#########
Changelog
#########

This page contains information about what has changed in each new version of MOLA.

*****************
v2 compared to v1 
*****************

===============
💡 New features
===============

* MOLA may be now used with the solvers SoNICS and Fast  
* Parametric studies are easy to launch with the WorkflowManager 

=======================
🚀 Feature improvements
=======================

* Extractions are more modular and user-friendly (➥ :ref:`inputs-extractions`)
* Error management has been improved for clarity 

==============
🚧 API changes
==============

* refer to sections :doc:`user_manual/workflow/introduction` and :doc:`user_manual/workflow/inputs`.

================================================================
:fas:`person-digging;sd-text-warning` Not yet transfered from v1
================================================================

* Body force method
* 2D airfoils polars
* interfaces for the following low or mid-fidelty tools: VPM, XFoil, BEMT
* Post-processing functions (except the *turbo* interface with the Workflow **turbomachinery** that is already available)

==================
💻 For developpers
==================

* better structure of the source code
* better code quality
* test base with unit, integration and user_case tests
* source code more easily extended in the future
